EKF SUR-UART — ekfsm documentation

# EKF SUR-UART

## Inventory

The inventory function provides access to the inventory, such as the vendor, model, serial number (taken from the board’s EEPROM), and revision (from the board’s GPIO device).

Method | Description | Example Value
`vendor()` | Get the board vendor | `EKF`
`model()` | Get the board model | `SUR-UART`
`serial()` | Get the board serial number | `12345678`
`revision()` | Get the board revision | `1`

## Thermal and Humidity Sensor (Object: th)

The EKF SUR-UART board has a built-in temperature and humidity sensor HDC2010. The sensor is connected to the board’s I2C bus.

Method | Description | Example Value
`temperature()` | Get the temperature | `-10`
`humidity()` | Get the humidity | `50`

## Front Panel LEDs (Object: led_a, led_b, led_c, led_d)

The EKF SUR-UART board has eight triple-color front panel LEDs. Two of them form one group accessible by on of the four objects led_a, led_b, led_c, led_d.

Method | Description | Example Value
`set()` | Set the color of a LED | `0`, `red`